# Changelog for releases

## v1.0.0
- `orientation_to_neighbor` 45, 135, 225, and 315 degrees are all considered `east_west`. Previously, 45 and 225 degrees were considered `north_south`.

## v0.0.0
- Initial release
